BuoyTheme class
Floating-menu palette, matching @buoy-gg/floating-tools-core colors.ts
and shared-ui's buoyColors (gameUIColors.ts).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- base → const Color
- border → const Color
- card → const Color
- dialBackdrop → const Color
- Dial backdrop: rgba(0, 0, 0, 0.85) — dialColors.dialBackdrop.
- error → const Color
- hover → const Color
- info → const Color
- muted → const Color
- Muted gray for secondary elements (buoyColors.textMuted).
- panel → const Color
- Dark panel background (buoyColors.card).
- secondary → const Color
- Primary text color (buoyColors.text).
- teal → const Color
- Buoy teal — primary/success/active/drag accent.
- textSecondary → const Color
- warning → const Color